******************************
The sherpa.utils.random module
******************************

.. currentmodule:: sherpa.utils.random

.. automodule:: sherpa.utils.random

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      chisquare
      choice
      integers
      multivariate_normal
      normal
      poisson_noise
      random
      standard_normal
      uniform
